mgkit.mappings package
======================

Submodules
----------

.. toctree::

   mgkit.mappings.cazy
   mgkit.mappings.eggnog
   mgkit.mappings.enzyme
   mgkit.mappings.go
   mgkit.mappings.pandas_map
   mgkit.mappings.taxon
   mgkit.mappings.utils

Module contents
---------------

.. automodule:: mgkit.mappings
   :members:
   :undoc-members:
   :show-inheritance:
